import { TypedUseSelectorHook, useDispatch, useSelector } from 'react-redux';
import { selectGraphQueryResult } from './graphQueryResultSlice';
import { schemaGraph, selectSchemaLayout, schemaSettingsState } from './schemaSlice';
import type { RootState, AppDispatch } from './store';
import { configState } from '@graphpolaris/shared/lib/data-access/store/configSlice';
import {
  queryBuilderSettingsState,
  selectQuerybuilderGraph,
  selectQuerybuilderHash,
} from '@graphpolaris/shared/lib/data-access/store/querybuilderSlice';
import { sessionCacheState } from './sessionSlice';
import { authState } from './authSlice';
import { visualizationState } from './visualizationSlice';
import { allMLEnabled, selectML } from './mlSlice';
import { searchResultState, searchResultData, searchResultSchema, searchResultQB } from './searchResultSlice';

// Use throughout your app instead of plain `useDispatch` and `useSelector`
export const useAppDispatch: () => AppDispatch = useDispatch;
// export const useAppDispatch = () => useDispatch<AppDispatch>();
export const useAppSelector: TypedUseSelectorHook<RootState> = useSelector;

/** Gives the graphQueryResult from the store */
export const useGraphQueryResult = () => useAppSelector(selectGraphQueryResult);

// Gives the schema form the store (as a graphology object)
export const useSchemaGraph = () => useAppSelector(schemaGraph);
export const useSchemaSettings = () => useAppSelector(schemaSettingsState);

// Gives the schema form the store (as a graphology object)
export const useSchemaLayout = () => useAppSelector(selectSchemaLayout);
export const useQuerybuilderGraph = () => useAppSelector(selectQuerybuilderGraph);
export const useQuerybuilderHash = () => useAppSelector(selectQuerybuilderHash);
export const useQuerybuilderSettings = () => useAppSelector(queryBuilderSettingsState);

// Overall Configuration of the app
export const useConfig = () => useAppSelector(configState);
export const useSessionCache = () => useAppSelector(sessionCacheState);
export const useAuthorizationCache = () => useAppSelector(authState);

// Machine Learning Slices
export const useML = () => useAppSelector(selectML);
export const useMLEnabledHash = () => useAppSelector(allMLEnabled);

// Search Result Slices
export const useSearchResult = () => useAppSelector(searchResultState);
export const useSearchResultData = () => useAppSelector(searchResultData);
export const useSearchResultSchema = () => useAppSelector(searchResultSchema);
export const useSearchResultQB = () => useAppSelector(searchResultQB);

// Visualization Slices
export const useVisualizationState = () => useAppSelector(visualizationState);
