/**
 * This program has been developed by a student from the bachelor Information Science at
 * Utrecht University within the Research Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

import { GeoGraphType, Viewport, Coordinates } from './types';
import * as d3 from 'd3';

export const calcMaxWidth = (viewport: Viewport): number => {
  const vpBounds: number[] = viewport.getBounds();
  return Math.sqrt(Math.pow(vpBounds[0] - vpBounds[2], 2) + Math.pow(vpBounds[1] - vpBounds[3], 2));
};

export const getColorFromScale = (prediction: number, colorScale: d3.ScaleLinear<number, string>): [number, number, number] => {
  const color = colorScale(prediction);
  const rgb: number[] = color
    .replace(/[^\d,]/g, '')
    .split(',')
    .map(Number);
  return [100, 0, 0];
};

export const calcAverageCoordinates = (lat: number[], long: number[]): [number, number] => {
  return [lat.reduce((p, c) => p + c, 0) / lat.length, long.reduce((p, c) => p + c, 0) / long.length];
};

export const calcNodeDistance = (source: Coordinates, target: Coordinates): number => {
  return Math.sqrt(Math.pow(source[0] - target[0], 2) + Math.pow(source[1] - target[1], 2));
};

export const getKeys = (graph: GeoGraphType, prefix = '', paths = { nodes: new Set(), edges: new Set() }) => {
  for (const key in graph) {
    if (typeof graph[key] === 'object' && graph[key] !== null) {
      if (Array.isArray(graph[key])) {
        const newPrefix = prefix ? `${prefix}.${key}` : key;
        for (let i = 0; i < graph[key].length; i++) {
          getKeys(graph[key][i], newPrefix, paths);
        }
      } else {
        const newPrefix = prefix ? `${prefix}.${key}` : key;
        getKeys(graph[key], newPrefix, paths);
      }
    } else {
      const path = prefix ? `${prefix}.${key}` : key;
      if (prefix.startsWith('nodes')) {
        paths.nodes.add(path);
      } else if (prefix.startsWith('edges')) {
        paths.edges.add(path);
      }
    }
  }
  return paths;
};
