/**
 * This program has been developed by students from the bachelor Computer Science at
 * Utrecht University within the Software Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

/* istanbul ignore file */
/* The comment above was added so the code coverage wouldn't count this file towards code coverage.
 * We do not test components/renderfunctions/styling files.
 * See testing plan for more details.*/

import React from 'react';
import { VariableSizeList, ListChildComponentProps } from 'react-window';
import styles from './OptimizedAutocomplete.module.scss';

const LISTBOX_PADDING = 8; // px

function renderRow(props: ListChildComponentProps) {
  const { data, index, style } = props;
  return React.cloneElement(data[index], {
    style: {
      ...style,
      top: (style.top as number) + LISTBOX_PADDING,
    },
  });
}

const OuterElementContext = React.createContext({});

// eslint-disable-next-line react/display-name
const OuterElementType = React.forwardRef<HTMLDivElement>((props, ref) => {
  const outerProps = React.useContext(OuterElementContext);
  return <div ref={ref} {...props} {...outerProps} />;
});

function useResetCache(data: any) {
  const ref = React.useRef<VariableSizeList>(null);
  React.useEffect(() => {
    if (ref.current != null) {
      ref.current.resetAfterIndex(0, true);
    }
  }, [data]);
  return ref;
}

// Adapter for react-window
const ListboxComponent = React.forwardRef<HTMLDivElement>(function ListboxComponent(props: any, ref) {
  const { children, ...other } = props;
  const itemData = React.Children.toArray(children);
  const itemCount = itemData.length;
  const itemSize = 36;

  return <div ref={ref}></div>;
});

const renderGroup = (params: any) => [<div key={params.key}>{params.group}</div>, params.children];

type OptimizedAutocomplete = {
  currentValue: string;
  options: string[];
  useMaterialStyle?: { label: string; helperText: string };
  /** Called when the value of the input field changes. */
  onChange?(value: string): void;
  /** Called when the user leaves focus of the input field. */
  onLeave?(value: string): void;
};
/** Renders the autocomplete input field with the given props. */
export default function OptimizedAutocomplete(props: OptimizedAutocomplete) {
  let newValue = props.currentValue;
  console.log(props);

  return (
    <input
      id="optimized-autocomplete"
      style={{ width: 200 }}
      className={styles.listbox}
      // defaultValue={props.currentValue}
      placeholder={props.currentValue}
      // renderOption={(props, option, state) => <Typography noWrap>{option}</Typography>}
      onChange={(e) => {
        let value = e.target.value;
        console.log(value);

        newValue = value || '?';
        if (props.onChange) props.onChange(newValue);
      }}
      onBlur={() => {
        if (props.onLeave) props.onLeave(newValue);
      }}
      onKeyDown={(e: React.KeyboardEvent<HTMLInputElement>): void => {
        if (e.key == 'Enter' && props.onLeave) props.onLeave(newValue);
      }}
    />
  );
}
